..
    This file is part of Invenio.
    Copyright (C) 2015-2022 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 2.0.3 (released 2022-07-08)

- add redirection on user profile form submit
- allow updating preferences for read only profiles

Version 2.0.2 (released 2022-07-01)

- Style radio buttons and remove dotted bullet points in settings page.

Version 2.0.1 (released 2022-06-10)

- Fixes the Alembic recipe dependency for removing the userprofiles table.

Version 2.0.0 (released 2022-05-23)

- Changes the profile backend to use the new Invenio-Accounts 2.0 profile
  field instead of a separate database table.

- Adds support for allowing users to change their visibility settings.

Version 1.2.4 (released 2021-10-18)

- Unpin Flask 2

Version 1.2.3 (released 2021-07-12)

- Adds german translations

Version 1.2.2 (released 2021-05-17)

- Add config option to make user profiles form read-only

Version 1.2.1 (released 2020-12-17)

- Add theme dependent icons.

Version 1.2.0 (released 2020-12-09)

- Marked strings for translation
- Added Turkish translation
- Changes `cancel` button's color
- Integrates Semantic-UI templates
- Removes example app

Version 1.1.1 (released 2020-05-11)

- Minimum version of Invenio-Accounts bumped to v1.2.1 due WTForms moving the
  email validation to an optional dependency

Version 1.1.0 (released 2020-03-11)

- Change Flask dependency management to invenio-base
- drop Python 2.7 support

Version 1.0.1 (released 2018-05-25)

- Flask v1.0 support.

Version 1.0.0 (released 2018-03-23)

- Initial public release.
